package sportsDAO;

import donnees.Discipline;
import donnees.Sport;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.HashSet;
import java.util.Set;

/**
 * DAO pour la classe/table Sport avec implémentation en JDBC
 * @author Eric
 */
public class DAO_JDBC_Sport extends DAO<Sport> {

    private Connection connection = null;

    protected Set<Discipline> getDisciplinesSport(Sport sport) throws SQLException {
        Statement req = connection.createStatement();
        ResultSet res = req.executeQuery("SELECT * FROM DISCIPLINE WHERE CODE_SPORT=" + sport.getCodeSport());

        //System.out.println(" Les disciplines du sport " + sport.getIntitule());
        HashSet<Discipline> disciplines = new HashSet<>();
        Discipline disc;
        while (res.next()) {
            //System.out.println(" -> " + res.getString(2));
            disc = new Discipline(res.getInt(1), res.getString(2), sport);
            disciplines.add(disc);
        }
        return disciplines;
    }

    @Override
    public Sport find(int id) throws DAOException {
        try {
            Statement req = connection.createStatement();
            ResultSet res = req.executeQuery("SELECT * FROM SPORT WHERE CODE_SPORT =" + id);
            if (res.next()) {
                Sport sport = new Sport();
                sport.setCodeSport(res.getInt(1));
                sport.setIntitule(res.getString(2));
                // reste à charger les disciplines : très lourd !
                sport.setDisciplines(this.getDisciplinesSport(sport));
                return sport;
            } else {
                throw new DAOException("Le sport d'identifiant " + id + " n'existe pas");
            }
        } catch (Exception e) {
            throw new DAOException("Problème technique (" + e.getMessage() + ")");
        }
    }

    @Override
    public void create(Sport sport) throws DAOException {
        try {
            Statement req = connection.createStatement();
            ResultSet res = req.executeQuery("SELECT MAX(CODE_SPORT) FROM SPORT");
            res.next();
            int codeSport = res.getInt(1);
            codeSport++;
            // positionne la clé primaire générée du sport
            // le contenu initial de codeSport n'est donc pas pris en compte
            sport.setCodeSport(codeSport);

            PreparedStatement reqParam = connection.prepareStatement("INSERT INTO SPORT VALUES (?,?)");
            reqParam.setInt(1, sport.getCodeSport());
            reqParam.setString(2, sport.getIntitule());
            int nb = reqParam.executeUpdate();
        } catch (Exception e) {
            throw new DAOException("Problème technique (" + e.getMessage() + ")");
        }
    }

    @Override
    public void update(Sport sport) throws DAOException {
        try {
            PreparedStatement reqParam = connection.prepareStatement("UPDATE SPORT SET INTITULE = ? WHERE CODE_SPORT = ?");
            reqParam.setString(1, sport.getIntitule());
            reqParam.setInt(2, sport.getCodeSport());
            int nb = reqParam.executeUpdate();
        } catch (Exception e) {
            throw new DAOException("Problèle technique (" + e.getMessage() + ")");
        }
    }

    @Override
    public void delete(Sport sport) throws DAOException {
        try {
            // on efface les disciplines du sport avant d'effacer le sport
            PreparedStatement reqParam = connection.prepareStatement("DELETE FROM DISCIPLINE WHERE CODE_SPORT = ?");
            reqParam.setInt(1, sport.getCodeSport());
            int nb = reqParam.executeUpdate();

            // on efface le sport
            reqParam = connection.prepareStatement("DELETE FROM SPORT WHERE CODE_SPORT = ?");
            reqParam.setInt(1, sport.getCodeSport());
            nb = reqParam.executeUpdate();
        } catch (Exception e) {
            throw new DAOException("Problème technique (" + e.getMessage() + ")");
        }
    }

    public DAO_JDBC_Sport() throws DAOException {
        this.connection = SQLConnection.getConnection();
    }
}
